=encoding utf8

=head1 NAME

Tok::Latn - Package for language Tok

=cut

package Locale::CLDR::Locales::Tok::Latn;

# This file auto generated
#	on Sun 25 Feb 10:41:40 am GMT

use version;

our $VERSION = version->declare('v0.44.0');

use v5.10.1;
use mro 'c3';
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moo;

extends('Locale::CLDR::Locales::Tok');

no Moo;

1;
